#!/bin/bash

cd "$(dirname "$0")"

display_usage() {
    usage="Usage: $(basename "$0") [-v version] [-f local archive]
    
A script to update iserver to a specified version.
If no internet connection is available, a local archive can be used for updating.
Either '-v' or '-f' have to be set. If both options are supplied, '-v' is ignored.
It is recommended to stop the server process before starting the update procedure.

This script has to be located in the iserver installation directory.

Options:
    -h  show this usage information
    -v  version that should be downloaded and installed from www.inteligand.com, e.g. '1.1.8'
    -f  local iserver installation archive file (*.tar.gz)"
    echo "$usage"
}

archive=""
version=""
while getopts "v:f:h" option; do
    case "$option" in
    h)
        display_usage
        exit
        ;;
    v)
        version=$OPTARG
        echo "${v}"
        ;;
    f)
        archive=$OPTARG
        echo "${f}"
        ;;
    :)
        printf "missing argument for -%s\n" "$OPTARG" >&2
        display_usage
        exit 1
        ;;
    \?)
        printf "illegal option: -%s\n" "$OPTARG" >&2
        display_usage
        exit 1
        ;;
    esac
done
shift $((OPTIND - 1))

if [ -z "${version}" ] && [ -z "${archive}" ]; then
    display_usage
    exit 1
fi

if [ -z "${archive}" ]; then
    echo "Trying to download iserver version ${version} from https://www.inteligand.com/download/iserver/iserver_${version}_linux64.tar.gz..."
    wget https://www.inteligand.com/download/iserver/iserver_${version}_linux64.tar.gz .
    echo "Unpacking startup script and Java application"
    tar xvzf iserver_${version}_linux64.tar.gz --overwrite --strip=1 --wildcards "*jar" "*iserver" -C .
    echo "Removing downloaded archive"
    rm iserver_${version}_linux64.tar.gz
else
    echo "Unpacking startup script and Java application from local .tar.gz archive (${archive})"
    tar xvzf "${archive}" --overwrite --strip=1 --wildcards "*jar" "*iserver" -C .
fi

exit 0